import React from 'react'
import { grommet, Grommet, Box, Text, Button } from 'grommet'

type State = { readonly balance: number }

type Action =
    | { readonly type: 'deposit', readonly payload: number }
    | { readonly type: 'withdraw', readonly payload: number }

function reducer(state: State, action: Action): State {
    switch (action.type) {
        case 'deposit': {
            const value = action.payload;
            return { balance: state.balance + value };
        }
        case 'withdraw': {
            const value = action.payload;
            return { balance: state.balance - value };
        }
    }
}

const initialState: State = { balance: 0 }

const App = () => {

    const [state, dispatch] = React.useReducer(reducer, initialState);

    function deposit10() {
        dispatch({ type: 'deposit', payload: 10 });
    }

    function withdraw10() {
        dispatch({ type: 'withdraw', payload: 10 });
    }

    return (
        <Grommet full theme={grommet}>
            <Box align="center" justify="center" pad="small" background={{ "color": "status-ok", "image": "url('')" }} height="xlarge" flex={false} fill="vertical" direction="row" wrap overflow="auto">
                <Box background={{ "color": "white" }} round="medium">
                    <Box align="start" justify="start" pad="small" direction="row" alignSelf="start" />
                    <Box align="center" justify="center" pad="xsmall" margin="xsmall">
                        <Text textAlign="center">
                            Balance:
                        </Text>
                        <Text textAlign="center">
                            {state.balance}
                        </Text>
                        <Box align="center" justify="center" pad="small" direction="row-responsive" flex alignSelf="center" basis="xxsmall" gap="small" margin="xsmall">
                            <Button label="Deposit $10" onClick={deposit10} />
                            <Button label="Withdraw $10" onClick={withdraw10} />
                        </Box>
                    </Box>
                </Box>
            </Box>
        </Grommet>
    )
}
export default App;