import React from 'react'
import { grommet, Grommet, Box, Text, Button } from 'grommet'
import { Add, Clear, Subtract } from 'grommet-icons'

//const state = { count: 9 }

type State = { readonly count: number }

/*
type Action =
    | 'reset'
    | 'increment'
    | 'decrement'

function reducer(state: State, action: Action): State {
    switch (action) {
        case 'reset': return { count: 0 };
        case 'increment': return { count: state.count + 1 };
        case 'decrement': return { count: state.count - 1 };
    }
}
*/

type Action =
    | { readonly type: 'reset' }
    | { readonly type: 'increment' }
    | { readonly type: 'decrement' }

function reducer(state: State, action: Action): State {
    switch (action.type) {
        case 'reset': return { count: 0 };
        case 'increment': return { count: state.count + 1 };
        case 'decrement': return { count: state.count - 1 };
    }
}

const initialState = { count: 10 }

const App = () => {

    const [state, dispatch] = React.useReducer(reducer, initialState);

    function reset() {
        dispatch({ type: 'reset' });
    }

    function increment() {
        dispatch({ type: 'increment' });
    }

    function decrement() {
        dispatch({ type: 'decrement' });
    }

    return (
        <Grommet full theme={grommet}>
            <Box align="center" justify="center" pad="small" background={{ "color": "light-6", "image": "url('')" }} height="xlarge" flex={false} fill="vertical" direction="row" wrap overflow="auto">
                <Box background={{ "color": "white" }} round="medium" margin="small">
                    <Box align="center" justify="center" pad="xsmall" margin="small" direction="row">
                        <Text textAlign="center" margin="small">
                            Counter:
                        </Text>
                        <Text>
                            {state.count}
                        </Text>
                        <Box align="center" justify="center" pad="small" direction="row-responsive" flex alignSelf="center" basis="xxsmall" gap="small" margin="xsmall">
                            <Button primary={false} icon={<Add />} plain={false} onClick={increment} />
                            <Button primary={false} icon={<Clear />} plain={false} onClick={reset} />
                            <Button icon={<Subtract />} plain={false} onClick={decrement} />
                        </Box>
                    </Box>
                </Box>
            </Box>
        </Grommet>
    )
}

export default App;